<?php
session_start();
require_once 'config.php';
$pdo = getConexaoInterna();

if ($_SESSION['user_role'] !== 'admin') die("Acesso negado.");

$mensagem = "";
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Salva as mensagens personalizadas do robô
    file_put_contents('msg_robo_hoje.txt', $_POST['msg_hoje']);
    file_put_contents('msg_robo_3d.txt', $_POST['msg_3d']);
    file_put_contents('msg_robo_7d.txt', $_POST['msg_7d']);
    $mensagem = "<div class='alert success'>Configurações do Robô salvas!</div>";
}

$msg_hoje = file_exists('msg_robo_hoje.txt') ? file_get_contents('msg_robo_hoje.txt') : "Seu plano vence hoje!";
?>
<div class="api-card">
    <h3><i class="fas fa-robot"></i> Configurar Máquina de Vendas (Robô)</h3>
    <form method="POST">
        <div class="form-group">
            <label>Mensagem: Vence Hoje</label>
            <textarea name="msg_hoje" class="form-control"><?php echo $msg_hoje; ?></textarea>
        </div>
        <button type="submit" class="btn-salvar">SALVAR REGRAS DO ROBÔ</button>
    </form>
</div>
