<?php
// 1. Entra fisicamente na pasta original (invisível)
chdir(__DIR__ . '/../xtreamui/api');

// 2. Finge para o sistema de rotas que estamos no arquivo original
$_SERVER['REQUEST_URI'] = '/xtreamui/api/webhook_pagamentos.php' . (!empty($_SERVER['QUERY_STRING']) ? '?' . $_SERVER['QUERY_STRING'] : '');
$_SERVER['SCRIPT_NAME'] = '/xtreamui/api/webhook_pagamentos.php';

// 3. Executa o webhook oficial
require_once 'webhook_pagamentos.php';