<?php
// Motor do Robô Financeiro - Versão 2.0
require_once 'config.php';
$pdo_int = getConexaoInterna();
$pdo_ext = getConexaoAtiva();

// 1. VERIFICA SE O ROBÔ ESTÁ LIGADO
$conf = $pdo_int->query("SELECT * FROM robo_financeiro_config WHERE id = 1")->fetch(PDO::FETCH_ASSOC);
if (!$conf || $conf['status'] == 0) {
    die("ROBÔ DESLIGADO PELO ADMINISTRADOR.");
}

$agora = time();

// --- LOGICA DE COBRANÇA HOJE ---
$hoje_inicio = strtotime("today 00:00:00");
$hoje_fim = strtotime("today 23:59:59");

// Busca no banco do Xtream UI (ou interno) quem vence hoje
$stmt = $pdo_ext->prepare("SELECT id, username, whatsapp FROM users WHERE exp_date BETWEEN ? AND ? AND enabled = 1");
$stmt->execute([$hoje_inicio, $hoje_fim]);
$clientes = $stmt->fetchAll(PDO::FETCH_ASSOC);

foreach($clientes as $cli) {
    // Personaliza a mensagem
    $mensagem_final = str_replace("#nome#", $cli['username'], $conf['msg_hoje']);
    
    // Registra o log no banco interno
    $pdo_int->prepare("INSERT INTO robo_financeiro_logs (cliente_id, cliente_user, tipo, mensagem) VALUES (?, ?, 'hoje', ?)")
            ->execute([$cli['id'], $cli['username'], $mensagem_final]);
            
    echo "Cobrando hoje: " . $cli['username'] . "\n";
}

echo "ROBÔ FINALIZOU O TRABALHO COM SUCESSO!";
?>
